==> zio-aws-machinelearning_2.13-5.17.124.1-sources.jar: zio/aws/machinelearning/model/DescribeEvaluationsResponse.scala <==
package zio.aws.machinelearning.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.machinelearning.model.primitives.StringType
import scala.jdk.CollectionConverters._
final case class DescribeEvaluationsResponse(
    results: Option[Iterable[zio.aws.machinelearning.model.Evaluation]] = None,
    nextToken: Option[StringType] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.machinelearning.model.DescribeEvaluationsResponse = {
    import DescribeEvaluationsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.machinelearning.model.DescribeEvaluationsResponse
      .builder()
      .optionallyWith(
        results.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.results)
      .optionallyWith(
        nextToken.map(value => StringType.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.machinelearning.model.DescribeEvaluationsResponse.ReadOnly =
    zio.aws.machinelearning.model.DescribeEvaluationsResponse
      .wrap(buildAwsValue())
}
object DescribeEvaluationsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.machinelearning.model.DescribeEvaluationsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.machinelearning.model.DescribeEvaluationsResponse =
      zio.aws.machinelearning.model.DescribeEvaluationsResponse(
        results.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def results: Option[List[zio.aws.machinelearning.model.Evaluation.ReadOnly]]
    def nextToken: Option[StringType]
    def getResults: ZIO[Any, AwsError, List[
      zio.aws.machinelearning.model.Evaluation.ReadOnly
    ]] = AwsError.unwrapOptionField("results", results)
    def getNextToken: ZIO[Any, AwsError, StringType] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.machinelearning.model.DescribeEvaluationsResponse
  ) extends zio.aws.machinelearning.model.DescribeEvaluationsResponse.ReadOnly {
    override val results
        : Option[List[zio.aws.machinelearning.model.Evaluation.ReadOnly]] =
      scala
        .Option(impl.results())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.machinelearning.model.Evaluation.wrap(item)
          }.toList
        )
    override val nextToken: Option[StringType] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.machinelearning.model.primitives.StringType(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.machinelearning.model.DescribeEvaluationsResponse
  ): zio.aws.machinelearning.model.DescribeEvaluationsResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-machinelearning_2.13-5.17.152.1-sources.jar: zio/aws/machinelearning/model/DescribeEvaluationsResponse.scala <==
package zio.aws.machinelearning.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.machinelearning.model.primitives.StringType
import scala.jdk.CollectionConverters._
final case class DescribeEvaluationsResponse(
    results: Option[Iterable[zio.aws.machinelearning.model.Evaluation]] = None,
    nextToken: Option[StringType] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.machinelearning.model.DescribeEvaluationsResponse = {
    import DescribeEvaluationsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.machinelearning.model.DescribeEvaluationsResponse
      .builder()
      .optionallyWith(
        results.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.results)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly
      : zio.aws.machinelearning.model.DescribeEvaluationsResponse.ReadOnly =
    zio.aws.machinelearning.model.DescribeEvaluationsResponse
      .wrap(buildAwsValue())
}
object DescribeEvaluationsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.machinelearning.model.DescribeEvaluationsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.machinelearning.model.DescribeEvaluationsResponse =
      zio.aws.machinelearning.model.DescribeEvaluationsResponse(
        results.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def results: Option[List[zio.aws.machinelearning.model.Evaluation.ReadOnly]]
    def nextToken: Option[StringType]
    def getResults: ZIO[Any, AwsError, List[
      zio.aws.machinelearning.model.Evaluation.ReadOnly
    ]] = AwsError.unwrapOptionField("results", results)
    def getNextToken: ZIO[Any, AwsError, StringType] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.machinelearning.model.DescribeEvaluationsResponse
  ) extends zio.aws.machinelearning.model.DescribeEvaluationsResponse.ReadOnly {
    override val results
        : Option[List[zio.aws.machinelearning.model.Evaluation.ReadOnly]] =
      scala
        .Option(impl.results())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.machinelearning.model.Evaluation.wrap(item)
          }.toList
        )
    override val nextToken: Option[StringType] =
      scala.Option(impl.nextToken()).map(value => value: StringType)
  }
  def wrap(
      impl: software.amazon.awssdk.services.machinelearning.model.DescribeEvaluationsResponse
  ): zio.aws.machinelearning.model.DescribeEvaluationsResponse.ReadOnly =
    new Wrapper(impl)
}
